@@ -26,6 +26,7 @@ import pbr.version
 
 from keystone.cmd import bootstrap
 from keystone.cmd import doctor
+from keystone.cmd import idutils
 from keystone.common import driver_hints
 from keystone.common import fernet_utils
 from keystone.common import jwt_utils
@@ -196,6 +197,73 @@ class BootStrap(BaseApp):
         klass.do_bootstrap()
 
 
+class ProjectSetup(BaseApp):
+    """Create project with specified UUID."""
+
+    name = 'project_setup'
+
+    def __init__(self):
+        self.identity = idutils.Identity()
+
+    @classmethod
+    def add_argument_parser(cls, subparsers):
+        parser = super(ProjectSetup, cls).add_argument_parser(subparsers)
+        parser.add_argument('--project-name', default=None, required=True,
+                            help='The name of the keystone project being'
+                            ' created.')
+        parser.add_argument('--project-id', default=None,
+                            help='The UUID of the keystone project being'
+                            ' created.')
+        return parser
+
+    def do_project_setup(self):
+        """Create project with specified UUID."""
+        self.identity.project_name = CONF.command.project_name
+        self.identity.project_id = CONF.command.project_id
+        self.identity.project_setup()
+
+    @classmethod
+    def main(cls):
+        klass = cls()
+        klass.do_project_setup()
+
+
+class UserSetup(BaseApp):
+    """Create user with specified UUID."""
+
+    name = 'user_setup'
+
+    def __init__(self):
+        self.identity = idutils.Identity()
+
+    @classmethod
+    def add_argument_parser(cls, subparsers):
+        parser = super(UserSetup, cls).add_argument_parser(subparsers)
+        parser.add_argument('--username', default=None, required=True,
+                            help='The username of the keystone user that'
+                            ' is being created.')
+        parser.add_argument('--user-password-plain', default=None,
+                            required=True,
+                            help='The plaintext password for the keystone'
+                            ' user that is being created.')
+        parser.add_argument('--user-id', default=None,
+                            help='The UUID of the keystone user being '
+                            'created.')
+        return parser
+
+    def do_user_setup(self):
+        """Create user with specified UUID."""
+        self.identity.user_name = CONF.command.username
+        self.identity.user_password = CONF.command.user_password_plain
+        self.identity.user_id = CONF.command.user_id
+        self.identity.user_setup()
+
+    @classmethod
+    def main(cls):
+        klass = cls()
+        klass.do_user_setup()
+
+
 class Doctor(BaseApp):
     """Diagnose common problems with keystone deployments."""
 
@@ -351,6 +419,47 @@ class DbVersion(BaseApp):
         print(upgrades.get_db_version())
 
 
+class ResetLastActive(BaseApp):
+    """Reset null values for all users to current time."""
+
+    name = "reset_last_active"
+
+    @classmethod
+    def add_argument_parser(cls, subparsers):
+        parser = super().add_argument_parser(subparsers)
+        parser.add_argument(
+            '--force',
+            action='store_true',
+            help='Write to the database without asking for confirmation',
+        )
+        return parser
+
+    @staticmethod
+    def main():
+        if not CONF.command.force:
+            confirm = input(
+                "Security Warning: reset_last_active  will update all users\n"
+                "in the database with a NULL value for last_active_at to be\n"
+                "last active at the current time.  This includes users that\n"
+                "have never logged in.  If your Keystone deployment is\n"
+                "configured to use disable_user_account_days_inactive, these\n"
+                "users will still be enabled and won't be disabled until the\n"
+                "configured amount of time has passed after this command is\n"
+                "run.\n"
+                "Are you sure you want to continue [y/N]? "
+            )
+            if confirm.lower() not in ('y', 'yes'):
+                raise SystemExit('reset_last_active aborted.')
+
+        LOG.debug(
+            "Resetting null values to current time %s",
+            datetime.datetime.utcnow,
+        )
+        drivers = backends.load_backends()
+        identity_api = drivers['identity_api']
+        identity_api.reset_last_active()
+
+
 class BasePermissionsSetup(BaseApp):
     """Common user/group setup for file permissions."""
 
@@ -1297,12 +1406,15 @@ CMDS = [
     MappingPopulate,
     MappingPurge,
     MappingEngineTester,
+    ProjectSetup,
     ReceiptRotate,
     ReceiptSetup,
+    ResetLastActive,
     SamlIdentityProviderMetadata,
     TokenRotate,
     TokenSetup,
-    TrustFlush
+    TrustFlush,
+    UserSetup
 ]
 
 
